@@ -81,20 +81,14 @@ impl Show for &[Location] {
     }
 }
 
-pub(crate) trait CloudLocation {
-    const PREFIX: &'static str;
-
-    fn as_str(&self) -> &'static str;
-}
-
 #[derive(Debug, Error)]
 #[error(r#"Invalid {vendor} region "{region}""#)]
-pub struct InvalidRegion {
+pub struct InvalidLocation {
     vendor: String,
     region: String,
 }
 
-impl InvalidRegion {
+impl InvalidLocation {
     pub(crate) fn new(vendor: &str, region: &str) -> Self {
         let vendor = vendor.to_string();
         let region = region.to_string();
