@@ -59,6 +59,8 @@ pub(crate) struct Cli {
     token: Option<String>,
     #[structopt(long, global = true, help = "Show results as JSON")]
     json: bool,
+    #[structopt(help = "Configuration profile to use", long, short, env = "SHPROFILE")]
+    profile: Option<String>,
     #[structopt(short, long, global = true)]
     verbose: bool,
     #[structopt(subcommand)]
@@ -559,13 +561,53 @@ enum Command {
     SelfUpdate,
 }
 
+impl Command {
+    fn requires_api_access(&self) -> bool {
+        match self {
+            Command::Login => false,
+            Command::CreateState { .. } => true,
+            Command::DeleteState { .. } => true,
+            Command::ListStates => true,
+            Command::ShowState { .. } => true,
+            Command::RegisterCluster { .. } => true,
+            Command::UnregisterCluster { .. } => true,
+            Command::UpdateCluster { .. } => true,
+            Command::ListClusters => true,
+            Command::ShowCluster { .. } => true,
+            Command::DiagnoseCluster { .. } => true,
+            Command::AddLocation { .. } => true,
+            Command::RemoveLocation { .. } => true,
+            Command::SetAvailability => true,
+            Command::SetOwner { .. } => true,
+            Command::UnsetOwner { .. } => true,
+            Command::CreateVolume { .. } => true,
+            Command::DeleteVolume { .. } => true,
+            Command::SetPrimary { .. } => true,
+            Command::ListVolumes { .. } => true,
+            Command::ShowVolumes { .. } => true,
+            Command::UninstallStatehub { .. } => false,
+            Command::SaveClusterToken { .. } => false,
+            Command::SetupConfigmap { .. } => false,
+            Command::InstallClusterCrd { .. } => false,
+            Command::UninstallClusterCrd { .. } => false,
+            Command::ListNamespaces { .. } => false,
+            Command::ListNodes { .. } => false,
+            Command::ListPods { .. } => false,
+            Command::ListRegions { .. } => false,
+            Command::SaveConfig => false,
+            Command::SelfUpdate => false,
+        }
+    }
+}
+
 impl Cli {
     pub(crate) async fn execute() -> anyhow::Result<()> {
         Self::from_args().dispatch().await
     }
 
     async fn config(&self) -> anyhow::Result<Config> {
-        let config = Config::load().unwrap_or_default();
+        let profile = self.profile.clone();
+        let config = Config::load(profile).unwrap_or_default();
         Ok(config)
     }
 
@@ -580,7 +622,7 @@ impl Cli {
         let statehub = StateHub::new(config, self.json, self.verbose);
 
         statehub.check_for_update().await;
-        if self.command != Command::Login {
+        if self.command.requires_api_access() {
             statehub.validate_auth().await?;
         }
 
