@@ -72,18 +72,18 @@ impl Config {
     }
 
     pub(crate) fn set_api(&mut self, profile: Option<&str>, api: impl ToString) {
-        let profile = profile.unwrap_or_else(|| self.profile.as_str()).to_string();
+        let profile = profile.unwrap_or(&self.profile).to_string();
         self.profiles.entry(profile).or_default().api = Some(api.to_string());
     }
 
     pub(crate) fn set_console(&mut self, profile: Option<&str>, console: impl ToString) {
-        let profile = profile.unwrap_or_else(|| self.profile.as_str()).to_string();
-        self.profiles.entry(profile).or_default().api = Some(console.to_string());
+        let profile = profile.unwrap_or(&self.profile).to_string();
+        self.profiles.entry(profile).or_default().console = Some(console.to_string());
     }
 
     pub(crate) fn set_token(&mut self, profile: Option<&str>, token: impl ToString) {
-        let profile = profile.unwrap_or_else(|| self.profile.as_str()).to_string();
-        self.profiles.entry(profile).or_default().api = Some(token.to_string());
+        let profile = profile.unwrap_or(&self.profile).to_string();
+        self.profiles.entry(profile).or_default().token = Some(token.to_string());
     }
 }
 
